@@ -28,6 +28,46 @@ sub distribution {
     return $self->{distribution};
 }
 
+sub meta_merge {
+    return {
+	'meta-spec'	=> {
+	    version	=> 2,
+	},
+	no_index	=> {
+	    directory	=> [ qw{ inc t xt } ],
+	},
+	resources	=> {
+	    bugtracker	=> {
+                web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Geo-Coder-Geocoder-US',
+                mailto  => 'wyant@cpan.org',
+            },
+	    license	=> 'http://dev.perl.org/licenses/',
+	    repository	=> {
+		type	=> 'git',
+		url	=> 'git://github.com/trwyant/perl-Geo-Coder-Geocoder-US.git',
+		web	=> 'https://github.com/trwyant/perl-Geo-Coder-Geocoder-US',
+	    },
+	}
+    };
+}
+
+sub notice {
+    warn <<"EOD";
+
+>>>> NOTICE <<<<\a\a\a
+
+The web site that this module in a front-end to, http://geocoder.us/,
+disappeared in late 2015. Without the web site, this module does
+nothing. If the web site or a reasonable facsimile does not reappear by
+mid-2016, this module WILL BE RETRACTED.
+
+EOD
+
+    sleep 6;
+
+    return;
+}
+
 sub requires {
     my ( $self, @extra ) = @_;
 ##  if ( ! $self->distribution() ) {
@@ -103,6 +143,21 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 meta_merge
+
+ use YAML;
+ print Dump( $meta->meta_merge() );
+
+This method returns a reference to a hash describing the meta-data which
+has to be provided by making use of the builder's C<meta_merge>
+functionality. This includes the C<no_index> and C<resources> data.
+
+=head2 notice
+
+ $meta->notice();
+
+This method displays the pending-retraction notice.
+
 =head2 requires
 
  use YAML;
@@ -147,7 +202,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2013 by Thomas R. Wyant, III
+Copyright (C) 2010-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
